aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/staging/tidspbridge/rmgr
diff options
context:
space:
mode:
authorRene Sapiens <rene.sapiens@ti.com>2010-07-09 21:24:05 -0500
committerGreg Kroah-Hartman <gregkh@suse.de>2010-07-22 10:45:36 -0700
commit318b5df99bbbe58eb9f80105d9534117ac2f25ce (patch)
tree23c80582ef2cedb12eee0f8ac521745ec2d5f266 /drivers/staging/tidspbridge/rmgr
parentstaging: ti dspbridge: Rename words with camel case (diff)
downloadlinux-dev-318b5df99bbbe58eb9f80105d9534117ac2f25ce.tar.xz
linux-dev-318b5df99bbbe58eb9f80105d9534117ac2f25ce.zip
staging: ti dspbridge: Rename words with camel case
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== puLen to len pulEntry to entry_pt pulFxnAddr to fxn_addr pulId to chan_id pulSegId to sgmt_id pVaBuf to va_buf pVirtualAddress to virtual_address pwMbVal to mbx_val pWord to word pXlatorAttrs to xlator_attrs registerFxn to register_fxn rootPersistent to root_prstnt sectionData to section_data sectionInfo to section_info sectionName to section_name sectName to sec_name ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/rmgr')
-rw-r--r--drivers/staging/tidspbridge/rmgr/dbdcd.c12
-rw-r--r--drivers/staging/tidspbridge/rmgr/drv.c6
-rw-r--r--drivers/staging/tidspbridge/rmgr/nldr.c12
-rw-r--r--drivers/staging/tidspbridge/rmgr/node.c14
4 files changed, 22 insertions, 22 deletions
diff --git a/drivers/staging/tidspbridge/rmgr/drv.c b/drivers/staging/tidspbridge/rmgr/drv.c
index f38123dee898..dc0c6292714b 100644
--- a/drivers/staging/tidspbridge/rmgr/drv.c
+++ b/drivers/staging/tidspbridge/rmgr/drv.c
@@ -1037,12 +1037,12 @@ void *mem_alloc_phys_mem(u32 byte_size, u32 ulAlign, OUT u32 * physical_address)
* Purpose:
* Free the given block of physically contiguous memory.
*/
-void mem_free_phys_mem(void *pVirtualAddress, u32 physical_address,
+void mem_free_phys_mem(void *virtual_address, u32 physical_address,
u32 byte_size)
{
- DBC_REQUIRE(pVirtualAddress != NULL);
+ DBC_REQUIRE(virtual_address != NULL);
if (!ext_phys_mem_pool_enabled)
- dma_free_coherent(NULL, byte_size, pVirtualAddress,
+ dma_free_coherent(NULL, byte_size, virtual_address,
physical_address);
}
diff --git a/drivers/staging/tidspbridge/rmgr/nldr.c b/drivers/staging/tidspbridge/rmgr/nldr.c
index 3eb1ae3c9bf3..198b69856635 100644
--- a/drivers/staging/tidspbridge/rmgr/nldr.c
+++ b/drivers/staging/tidspbridge/rmgr/nldr.c
@@ -299,7 +299,7 @@ static bool get_symbol_value(void *handle, void *parg, void *rmm_handle,
char *symName, struct dbll_sym_val **sym);
static int load_lib(struct nldr_nodeobject *nldr_node_obj,
struct lib_node *root, struct dsp_uuid uuid,
- bool rootPersistent,
+ bool root_prstnt,
struct dbll_library_obj **lib_path,
enum nldr_phase phase, u16 depth);
static int load_ovly(struct nldr_nodeobject *nldr_node_obj,
@@ -1243,7 +1243,7 @@ static bool get_symbol_value(void *handle, void *parg, void *rmm_handle,
*/
static int load_lib(struct nldr_nodeobject *nldr_node_obj,
struct lib_node *root, struct dsp_uuid uuid,
- bool rootPersistent,
+ bool root_prstnt,
struct dbll_library_obj **lib_path,
enum nldr_phase phase, u16 depth)
{
@@ -1300,7 +1300,7 @@ static int load_lib(struct nldr_nodeobject *nldr_node_obj,
kfree(psz_file_name);
/* Check to see if library not already loaded */
- if (DSP_SUCCEEDED(status) && rootPersistent) {
+ if (DSP_SUCCEEDED(status) && root_prstnt) {
lib_status =
find_in_persistent_lib_array(nldr_node_obj, root->lib);
/* Close library */
@@ -1374,7 +1374,7 @@ static int load_lib(struct nldr_nodeobject *nldr_node_obj,
/* If root library is NOT persistent, and dep library
* is, then record it. If root library IS persistent,
* the deplib is already included */
- if (!rootPersistent && persistent_dep_libs[i] &&
+ if (!root_prstnt && persistent_dep_libs[i] &&
*nldr_node_obj->pf_phase_split) {
if ((nldr_node_obj->pers_libs) >= MAXLIBS) {
status = -EILSEQ;
@@ -1386,7 +1386,7 @@ static int load_lib(struct nldr_nodeobject *nldr_node_obj,
&nldr_node_obj->pers_lib_table
[nldr_node_obj->pers_libs];
} else {
- if (rootPersistent)
+ if (root_prstnt)
persistent_dep_libs[i] = true;
/* Allocate library within phase */
@@ -1400,7 +1400,7 @@ static int load_lib(struct nldr_nodeobject *nldr_node_obj,
if (DSP_SUCCEEDED(status)) {
if ((status != 0) &&
- !rootPersistent && persistent_dep_libs[i] &&
+ !root_prstnt && persistent_dep_libs[i] &&
*nldr_node_obj->pf_phase_split) {
(nldr_node_obj->pers_libs)++;
} else {
diff --git a/drivers/staging/tidspbridge/rmgr/node.c b/drivers/staging/tidspbridge/rmgr/node.c
index 91a5d8c7d0a2..cdae2c88fbe1 100644
--- a/drivers/staging/tidspbridge/rmgr/node.c
+++ b/drivers/staging/tidspbridge/rmgr/node.c
@@ -248,7 +248,7 @@ static void fill_stream_def(struct node_object *hnode,
struct node_strmdef *pstrm_def,
struct dsp_strmattr *pattrs);
static void free_stream(struct node_mgr *hnode_mgr, struct stream_chnl stream);
-static int get_fxn_address(struct node_object *hnode, u32 * pulFxnAddr,
+static int get_fxn_address(struct node_object *hnode, u32 * fxn_addr,
u32 uPhase);
static int get_node_props(struct dcd_manager *hdcd_mgr,
struct node_object *hnode,
@@ -1762,13 +1762,13 @@ int node_get_attr(struct node_object *hnode,
* host and a node.
*/
int node_get_channel_id(struct node_object *hnode, u32 dir, u32 index,
- OUT u32 *pulId)
+ OUT u32 *chan_id)
{
enum node_type node_type;
int status = -EINVAL;
DBC_REQUIRE(refs > 0);
DBC_REQUIRE(dir == DSP_TONODE || dir == DSP_FROMNODE);
- DBC_REQUIRE(pulId != NULL);
+ DBC_REQUIRE(chan_id != NULL);
if (!hnode) {
status = -EFAULT;
@@ -1782,7 +1782,7 @@ int node_get_channel_id(struct node_object *hnode, u32 dir, u32 index,
if (dir == DSP_TONODE) {
if (index < MAX_INPUTS(hnode)) {
if (hnode->inputs[index].type == HOSTCONNECT) {
- *pulId = hnode->inputs[index].dev_id;
+ *chan_id = hnode->inputs[index].dev_id;
status = 0;
}
}
@@ -1790,7 +1790,7 @@ int node_get_channel_id(struct node_object *hnode, u32 dir, u32 index,
DBC_ASSERT(dir == DSP_FROMNODE);
if (index < MAX_OUTPUTS(hnode)) {
if (hnode->outputs[index].type == HOSTCONNECT) {
- *pulId = hnode->outputs[index].dev_id;
+ *chan_id = hnode->outputs[index].dev_id;
status = 0;
}
}
@@ -2819,7 +2819,7 @@ static void free_stream(struct node_mgr *hnode_mgr, struct stream_chnl stream)
* Purpose:
* Retrieves the address for create, execute or delete phase for a node.
*/
-static int get_fxn_address(struct node_object *hnode, u32 * pulFxnAddr,
+static int get_fxn_address(struct node_object *hnode, u32 * fxn_addr,
u32 uPhase)
{
char *pstr_fxn_name = NULL;
@@ -2850,7 +2850,7 @@ static int get_fxn_address(struct node_object *hnode, u32 * pulFxnAddr,
status =
hnode_mgr->nldr_fxns.pfn_get_fxn_addr(hnode->nldr_node_obj,
- pstr_fxn_name, pulFxnAddr);
+ pstr_fxn_name, fxn_addr);
return status;
}
diff --git a/drivers/staging/tidspbridge/rmgr/dbdcd.c b/drivers/staging/tidspbridge/rmgr/dbdcd.c
index a5cef434f4b1..992ff7346031 100644
--- a/drivers/staging/tidspbridge/rmgr/dbdcd.c
+++ b/drivers/staging/tidspbridge/rmgr/dbdcd.c
@@ -66,7 +66,7 @@ static int get_attrs_from_buf(char *psz_buf, u32 ul_buf_size,
enum dsp_dcdobjtype obj_type,
struct dcd_genericobj *gen_obj);
static void compress_buf(char *psz_buf, u32 ul_buf_size, s32 char_size);
-static char dsp_char2_gpp_char(char *pWord, s32 dsp_char_size);
+static char dsp_char2_gpp_char(char *word, s32 dsp_char_size);
static int get_dep_lib_info(IN struct dcd_manager *hdcd_mgr,
IN struct dsp_uuid *uuid_obj,
IN OUT u16 *num_libs,
@@ -534,7 +534,7 @@ func_end:
* ======== dcd_get_objects ========
*/
int dcd_get_objects(IN struct dcd_manager *hdcd_mgr,
- IN char *sz_coff_path, dcd_registerfxn registerFxn,
+ IN char *sz_coff_path, dcd_registerfxn register_fxn,
void *handle)
{
struct dcd_manager *dcd_mgr_obj = hdcd_mgr;
@@ -608,7 +608,7 @@ int dcd_get_objects(IN struct dcd_manager *hdcd_mgr,
object_type = atoi(token);
/*
* Apply registerFxn to the found DCD object.
* Possible actions include:
*
* 1) Register found DCD object.
@@ -616,7 +616,7 @@ int dcd_get_objects(IN struct dcd_manager *hdcd_mgr,
* 3) Add overlay node.
*/
status =
- registerFxn(&dsp_uuid_obj, object_type, handle);
+ register_fxn(&dsp_uuid_obj, object_type, handle);
if (DSP_FAILED(status)) {
/* if error occurs, break from while loop. */
break;
@@ -1376,13 +1376,13 @@ static void compress_buf(char *psz_buf, u32 ul_buf_size, s32 char_size)
* Purpose:
* Convert DSP char to host GPP char in a portable manner
*/
-static char dsp_char2_gpp_char(char *pWord, s32 dsp_char_size)
+static char dsp_char2_gpp_char(char *word, s32 dsp_char_size)
{
char ch = '\0';
char *ch_src;
s32 i;
- for (ch_src = pWord, i = dsp_char_size; i > 0; i--)
+ for (ch_src = word, i = dsp_char_size; i > 0; i--)
ch |= *ch_src++;
return ch;
@@ -608,7 +608,7 @@ int dcd_get_objects(IN struct dcd_manager *hdcd_mgr,
object_type = atoi(token);
/*
- * Apply registerFxn to the found DCD object.
+ * Apply register_fxn to the found DCD object.
* Possible actions include:
*